document.addEventListener("DOMContentLoaded", function () {
  let map, directionsService, directionsRenderer;
  let markers = [];
  function initMap() {
    map = new google.maps.Map(document.getElementById('map'), {
      zoom: 7,
    });

    directionsService = new google.maps.DirectionsService();
    directionsRenderer = new google.maps.DirectionsRenderer({
      map: map,
      suppressMarkers: true,
    });

    const pickupInput = document.getElementById('pickup');
    const pickupAutocomplete = new google.maps.places.Autocomplete(pickupInput);

    const viaInput = document.getElementById('via');
    const viaAutocomplete = new google.maps.places.Autocomplete(viaInput);

    const viaInputTwo = document.getElementById('viaTwo');
    const viaTwoAutocomplete = new google.maps.places.Autocomplete(viaInputTwo);

    const dropInput = document.getElementById('drops');
    const dropAutocomplete = new google.maps.places.Autocomplete(dropInput);

    pickupAutocomplete.addListener('place_changed', function () {
      calculateRoute();
    });

    dropAutocomplete.addListener('place_changed', function () {
      calculateRoute();
    });

    viaAutocomplete.addListener('place_changed', function () {
      calculateRoute();
    });

    viaTwoAutocomplete.addListener('place_changed', function () {
      calculateRoute();
    });
  }



function addMarker(location, title, icon) {
  console.log(`Adding marker at ${location} with title: ${title} icon: ${icon}` );

  const marker = new google.maps.Marker({
    position: location,
    map: map,
    title: title,
    icon: './images/' + icon,
  });

  marker.setMap(map);
}
  function calculateRoute() {
    const pickupLocation = document.getElementById('pickup').value;
    const dropLocation = document.getElementById('drops').value;
    const viaLocation = document.getElementById('via').value;
    const viaLocationTwo = document.getElementById('viaTwo').value;

    if (!pickupLocation || !dropLocation) {
      return;
    }

    const mapIframe = document.getElementById('map');
    let googleMapsUrl;

if (!viaLocation && !viaLocationTwo) {
  googleMapsUrl = `https://www.google.com/maps/embed/v1/directions?key=AIzaSyBrT6TBKJor6uQd0OKXKzLnpkKY5JniO4M&origin=${pickupLocation}&destination=${dropLocation}`;
} else {
  const waypoints = [];

  if (viaLocation) {
    waypoints.push(viaLocation);
  }

  if (viaLocationTwo) {
    waypoints.push(viaLocationTwo);
  }

  googleMapsUrl = `https://www.google.com/maps/embed/v1/directions?key=AIzaSyBrT6TBKJor6uQd0OKXKzLnpkKY5JniO4M&origin=${pickupLocation}&destination=${dropLocation}&waypoints=${waypoints.join('|')}`;
}

mapIframe.src = googleMapsUrl;

    // let googleMapsUrl;

    // if (!viaLocation && !viaLocationTwo) {
    //   googleMapsUrl = `https://www.google.com/maps/embed/v1/directions?key=AIzaSyBu3_x5ycCqC5PfVeelGrvKe3t2t_Qz_TU&origin=${pickupLocation}&destination=${dropLocation}`;
    // } else {
    //   const waypoints = [];

    //   if (viaLocation) {
    //     waypoints.push({
    //       location: viaLocation,
    //       stopover: true,
    //     });
    //   }

    //   if (viaLocationTwo) {
    //     waypoints.push({
    //       location: viaLocationTwo,
    //       stopover: true,
    //     });
    //   }

    //   googleMapsUrl = `https://www.google.com/maps/embed/v1/directions?key=AIzaSyBu3_x5ycCqC5PfVeelGrvKe3t2t_Qz_TU&origin=${pickupLocation}&destination=${dropLocation}&waypoints=${waypoints.map((wp) => `via:${wp.location}`).join('|')}`;
    // }

    // mapIframe.src = googleMapsUrl;

    const request = {
      origin: pickupLocation,
      destination: dropLocation,
      travelMode: 'DRIVING',
      waypoints: [],
    };

    if (viaLocation) {
      request.waypoints.push({
        location: viaLocation,
        stopover: true,
      });
    }

    if (viaLocationTwo) {
      request.waypoints.push({
        location: viaLocationTwo,
        stopover: true,
      });
    }

    directionsService.route(request, function (result, status) {
      if (status == 'OK') {
        directionsRenderer.setDirections(result);

        let totalDistance = 0;
        let totalDuration = 0;

        const routes = result.routes;
        for (let i = 0; i < routes.length; i++) {
          const route = routes[i];
          for (let j = 0; j < route.legs.length; j++) {
            totalDistance += route.legs[j].distance.value;
            totalDuration += route.legs[j].duration.value;
            const leg = route.legs[j];
            addMarker(leg.start_location, 'Pickup', 'red-circle.png');

            if (j === route.legs.length - 1) {
              addMarker(leg.end_location, 'Drop', 'red-circle.png');
            }

            if (j < route.legs.length - 1) {
              addMarker(leg.end_location, `Via ${j + 1}`, 'red-circle.png');
            }
          }
        }

        const totalDistanceInMiles = (totalDistance / 1609.344).toFixed(0);

        const hours = Math.floor(totalDuration / 3600);
        const minutes = Math.floor((totalDuration % 3600) / 60);

        const totalDurationText = `${hours} hrs ${minutes} mins`;

        // Display the distance and time in your form
        const inputDistance = document.getElementById('display_distance');
        inputDistance.value = `${totalDistanceInMiles}`;

        const inputTime = document.getElementById('Times');
        inputTime.value = totalDurationText;
      } else {
        alert("Error calculating the route");
      }
    });
  }

  initMap();
});


function formatDate(date) {
  const year = date.getUTCFullYear();
  const month = String(date.getUTCMonth() + 1).padStart(2, '0'); // Month is zero-based
  const day = String(date.getUTCDate()).padStart(2, '0');
  return `${day}/${month}/${year}`;

}

function updateDate() {
  const currentDate = new Date();
  const formattedDate = formatDate(currentDate);
  document.getElementById('dateInput').value = formattedDate;
}

// Function to get London time
function getLondonTime() {
  const options = {
    timeZone: 'Europe/London',
    hour12: false, // Use 24-hour format
    hour: '2-digit',
    minute: '2-digit',
  };
  const londonTime = new Date().toLocaleTimeString('en-US', options);
  return londonTime;
}

// Function to update the time input field with London time
function updateTime() {
  const timeInput = document.getElementById('timeInput');
  const londonTime = getLondonTime();
  timeInput.value = londonTime;
}

// Call the functions to update the input fields when the page loads
updateDate();
updateTime();

// Optionally, you can set up an interval to update the time input field regularly
// For example, to update every minute:
setInterval(updateTime, 60000);



$(document).ready(function () {
  var totalFare = 0;
  var pickupEntered = false;
  var dropEntered = false;
  var dropAutocomplete;
  var directionsService = new google.maps.DirectionsService();
  var inputTimeout; // Variable to hold the input delay timeout

  // An array to hold via locations
  var viaLocations = [];

  // Disable form submit on Enter key press
  $('form').on('keyup keypress', function (e) {
    var keyCode = e.keyCode || e.which;
    if (keyCode === 13) {
      e.preventDefault();
      return false;
    }
  });

  // Function to initialize Autocomplete for drop location
  function initializeDropAutocomplete() {
    dropAutocomplete = new google.maps.places.Autocomplete(document.getElementById('drops'));

    // Listen for the place_changed event on the Autocomplete object
    dropAutocomplete.addListener('place_changed', function () {
      totalFare = 0;
      var place = dropAutocomplete.getPlace();

      if (place.geometry && place.formatted_address) {
        // Place is fully resolved, calculate the fare
        $('#drops').val(place.formatted_address); // Update the input field with the resolved address
        calculateDistanceAndFare();
      } else {
        // Place is not fully resolved, clear the fare display
        $('#priceVal').val('');
      }
    });
  }

  // Initialize the drop location Autocomplete
  initializeDropAutocomplete();

  function calculateDistanceAndFare() {
    // Clear any previously set input timeout
    clearTimeout(inputTimeout);

    // Retrieve location values from the form
    var pickup = $('#pickup').val();
    var drop = $('#drops').val();
    var carType = $('#cartype').val();
    // var distanceText = $('#display_distance').val();

    if (pickup && drop) {
      // Clear viaLocations array to re-populate it
      viaLocations = [];

      // Iterate over via location input fields and populate the viaLocations array
      $('.via').each(function () {
        var viaLocation = $(this).val();
        if (viaLocation) {
          viaLocations.push({
            location: viaLocation,
            stopover: true // Consider the via location as a stopover
          });
        }
      });

      // Use the Directions API to calculate distance
      var request = {
        origin: pickup,
        destination: drop,
        waypoints: viaLocations, // Include via locations as waypoints
        optimizeWaypoints: true, // Optimize the order of waypoints
        travelMode: 'DRIVING'
      };

      directionsService.route(request, function (result, status) {
        if (status === 'OK' && result.routes && result.routes[0]) {
          var totalDistance = 0; // Total distance to sum all legs

          // Iterate over legs, including via legs, to sum distances
          result.routes[0].legs.forEach(function (leg) {
            totalDistance += leg.distance.value;
          });

          // Convert the total distance to text (e.g., "25.5 km")
          var distanceText = (totalDistance / 1609.344).toFixed(0);

          // Update the display with the calculated distance
          $('#display_distance').val(distanceText);

          // Calculate the fare based on the distance
          $.ajax({
            type: 'POST',
            url: 'action/Submit.php',
            data: {
              pickup: pickup,
              drop: drop,
              carType: carType,
              distance: distanceText
            },
            cache: false,
            success: function (response) {
              // Update the fare display with the calculated fare
              $('#priceVal').val(response);
            }
          });
        }
      });
    }
  }

  // Add event listeners to car type, pickup location, drop location, and via location inputs
  $('#cartype, #pickup, #drops, .via').on('input change', function () {
    totalFare = 0;
    calculateDistanceAndFare();
  });

  // Initially, calculate the fare based on the initial values if both locations are provided
  calculateDistanceAndFare();
});



  $(document).ready(function (){
    $('#addVia').click(function(){
      $('#viaTwo').toggle();
    });
  });

// $(document).ready(function(){
//   // Define the function to calculate fare
//   function calculateDistanceAndFare() {

//     // Retrieve location values from the form
//     var pickup = $('#pickup').val();
//     var drop = $('#drops').val();
//     var carType = $('#cartype').val();
//     var distance = $("#distance_display").val();
    
//     console.log("pickup", pickup)
//     console.log("drop", drop)
//     console.log("car", carType)
//     console.log("distance", distance)
    
    
//     if (pickup && drop) {
     
//             $.ajax({
//               type: 'POST',
//               url: './action/Submit.php',
//               data: {
//                 pickup: pickup,
//                 drop: drop,
//                 carType: carType,
//                 distance: distance
//               },
//               cache: false,
//               success: function (response) {
//                 console.log("response:", response);
//                 // Update the fare display with the calculated fare
//                 $('#priceVal').val( response);

//               },
//               error: function () {
//                 console.log("error")
//               }
//             });
//           } else {
//           console.log("dfdsfds")
//           }
//   }
  
//     // Add event listeners to car type, pickup location, and drop location inputs
//     $('#cartype, #pickup, #drops').on('input change', function () {
//       calculateDistanceAndFare();
//     });
  
//     // Initially, calculate the fare based on the initial values if both locations are provided
//     calculateDistanceAndFare();
// });
