// Make initMap a global function
let map, directionsService, directionsRenderer;

function initMap() {
  map = new google.maps.Map(document.getElementById('map'), {
    zoom: 7,
  });

  directionsService = new google.maps.DirectionsService();
  directionsRenderer = new google.maps.DirectionsRenderer({
    map: map,
    suppressMarkers: true,
  });

  const pickupInput = document.getElementById('pickup');
  const pickupAutocomplete = new google.maps.places.Autocomplete(pickupInput);

  const viaInput = document.getElementById('via');
  const viaAutocomplete = new google.maps.places.Autocomplete(viaInput);

  const dropInput = document.getElementById('drops');
  const dropAutocomplete = new google.maps.places.Autocomplete(dropInput);

  // Add event listener for input changes in the pickup, via, and drop inputs
  pickupAutocomplete.addListener('place_changed', calculateRoute);
  viaAutocomplete.addListener('place_changed', calculateRoute);
  dropAutocomplete.addListener('place_changed', calculateRoute);
}

// Route calculation function (unchanged)
function calculateRoute() {
  const pickupLocation = document.getElementById('pickup').value;
  const dropLocation = document.getElementById('drops').value;
  const viaLocation = document.getElementById('via').value;

  if (!pickupLocation || !dropLocation) return;

  const mapIframe = document.getElementById('map');
  let googleMapsUrl = `https://www.google.com/maps/embed/v1/directions?key=AIzaSyBrT6TBKJor6uQd0OKXKzLnpkKY5JniO4M&origin=${pickupLocation}&destination=${dropLocation}`;

  if (viaLocation) {
    const waypoints = encodeURIComponent(`via:${viaLocation}`);
    googleMapsUrl += `&waypoints=${waypoints}`;
  }
  
  mapIframe.src = googleMapsUrl;

  const request = {
    origin: pickupLocation,
    destination: dropLocation,
    travelMode: 'DRIVING',
    waypoints: viaLocation ? [{ location: viaLocation, stopover: true }] : [],
  };

  directionsService.route(request, function (result, status) {
    if (status === 'OK') {
      directionsRenderer.setDirections(result);

      let totalDistance = 0;
      let totalDuration = 0;
      const routes = result.routes;
      
      routes.forEach(route => {
        route.legs.forEach(leg => {
          totalDistance += leg.distance.value;
          totalDuration += leg.duration.value;
        });
      });

      const totalDistanceText = (totalDistance / 1609.344).toFixed(0);
      const totalDurationText = formatDuration(totalDuration);

      // document.getElementById('routeSummary').textContent = `Total Distance: ${totalDistanceText}, Total Duration: ${totalDurationText}`;
      // document.getElementById("display_distance").value = totalDistanceText;

    } else {
      alert("Error calculating the route");
    }
  });
}

// Duration formatting function (unchanged)
function formatDuration(durationInSeconds) {
  const hours = Math.floor(durationInSeconds / 3600);
  const minutes = Math.floor((durationInSeconds % 3600) / 60);
  return `${hours} hours ${minutes} minutes`;
}

// Ensure the DOM is fully loaded before using map-related elements
document.addEventListener("DOMContentLoaded", function () {
  // Your code that relies on DOM elements goes here
});
